from names import *
from random import randint

def get_name_gender_religion():
    religions = ('islam', 'christianity', 'other')
    genders = ('male', 'female')
    religion = religions[randint(0, 2)]
    gender = genders[randint(0, 1)]

    firstname = ""
    lastname = ""

    if religion == 'islam':
        if gender == 'male':
            firstname = arabic_male[randint(0, len(arabic_male) - 1)]
            lastname = arabic_surnames[randint(0, len(arabic_surnames) - 1)]
        else:
            firstname = arabic_female[randint(0, len(arabic_female) - 1)]
            lastname = arabic_surnames[randint(0, len(arabic_surnames) - 1)]
            
    elif religion == 'christianity':
        if gender == 'male':
            firstname = english_male[randint(0, len(english_male) - 1)]
            lastname = english_surnames[randint(0, len(english_surnames) - 1)]
        else:
            firstname = english_female[randint(0, len(english_female) - 1)]
            lastname = english_surnames[randint(0, len(english_surnames) - 1)]
    else:
        if gender == 'male':
            firstname = english_male[randint(0, len(english_male) - 1)]
            lastname = english_surnames[randint(0, len(english_surnames) - 1)]
        else:
            firstname = english_female[randint(0, len(english_female) - 1)]
            lastname = english_surnames[randint(0, len(english_surnames) - 1)]
        
    return firstname, lastname, gender, religion


countries_capital = {
    "Afghanistan": "Kabul",
    "Albania": "Tirana (Tirane)",
    "Algeria": "Algiers",
    "Andorra": "Andorra la Vella",
    "Angola": "Luanda",
    "Antigua and Barbuda": "Saint John's",
    "Argentina": "Buenos Aires",
    "Armenia": "Yerevan",
    "Australia": "Canberra",
    "Austria": "Vienna",
    "Azerbaijan": "Baku",
    "Bahamas": "Nassau",
    "Bahrain": "Manama",
    "Bangladesh": "Dhaka",
    "Barbados": "Bridgetown",
    "Belarus": "Minsk",
    "Belgium": "Brussels",
    "Belize": "Belmopan",
    "Benin": "Porto Novo",
    "Bhutan": "Thimphu",
    "Bolivia": "La Paz (administrative), Sucre (official)",
    "Bosnia and Herzegovina": "Sarajevo",
    "Botswana": "Gaborone",
    "Brazil": "Brasilia",
    "Brunei": "Bandar Seri Begawan",
    "Bulgaria": "Sofia",
    "Burkina Faso": "Ouagadougou",
    "Burundi": "Gitega",
    "Cambodia": "Phnom Penh",
    "Cameroon": "Yaounde",
    "Canada": "Ottawa",
    "Cape Verde": "Praia",
    "Central African Republic": "Bangui",
    "Chad": "N'Djamena",
    "Chile": "Santiago",
    "China": "Beijing",
    "Colombia": "Bogota",
    "Comoros": "Moroni",
    "Democratic Republic of the Congo": "Kinshasa",
    "Republic of the Congo": "Brazzaville",
    "Costa Rica": "San Jose",
    "Côte d'Ivoire (Ivory Coast)": "Yamoussoukro",
    "Croatia": "Zagreb",
    "Cuba": "Havana",
    "Cyprus": "Nicosia",
    "Czech Republic (Czechia)": "Prague",
    "Denmark": "Copenhagen",
    "Djibouti": "Djibouti",
    "Dominica": "Roseau",
    "Dominican Republic": "Santo Domingo",
    "East Timor": "Dili",
    "Ecuador": "Quito",
    "Egypt": "Cairo",
    "El Salvador": "San Salvador",
    "England": "London",
    "Equatorial Guinea": "Malabo",
    "Eritrea": "Asmara",
    "Estonia": "Tallinn",
    "Eswatini (Swaziland)": "Mbabana",
    "Ethiopia": "Addis Ababa",
    "Federated States of Micronesia": "Palikir",
    "Fiji": "Suva",
    "Finland": "Helsinki",
    "France": "Paris",
    "Gabon": "Libreville",
    "Gambia": "Banjul",
    "Georgia": "Tbilisi",
    "Germany": "Berlin",
    "Ghana": "Accra",
    "Greece": "Athens",
    "Grenada": "Saint George's",
    "Guatemala": "Guatemala City",
    "Guinea": "Conakry",
    "Guinea-Bissau": "Bissau",
    "Guyana": "Georgetown",
    "Haiti": "Port au Prince",
    "Honduras": "Tegucigalpa",
    "Hungary": "Budapest",
    "Iceland": "Reykjavik",
    "India": "New Delhi",
    "Indonesia": "Jakarta",
    "Iran": "Tehran",
    "Iraq": "Baghdad",
    "Ireland": "Dublin",
    "Israel": "Jerusalem (very limited international recognition)",
    "Italy": "Rome",
    "Jamaica": "Kingston",
    "Japan": "Tokyo",
    "Jordan": "Amman",
    "Kazakhstan": "Nur-Sultan",
    "Kenya": "Nairobi",
    "Kiribati": "Tarawa Atoll",
    "Kosovo": "Pristina",
    "Kuwait": "Kuwait City",
    "Kyrgyzstan": "Bishkek",
    "Laos": "Vientiane",
    "Latvia": "Riga",
    "Lebanon": "Beirut",
    "Lesotho": "Maseru",
    "Liberia": "Monrovia",
    "Libya": "Tripoli",
    "Liechtenstein": "Vaduz",
    "Lithuania": "Vilnius",
    "Luxembourg": "Luxembourg",
    "Madagascar": "Antananarivo",
    "Malawi": "Lilongwe",
    "Malaysia": "Kuala Lumpur",
    "Maldives": "Male",
    "Mali": "Bamako",
    "Malta": "Valletta",
    "Marshall Islands": "Majuro",
    "Mauritania": "Nouakchott",
    "Mauritius": "Port Louis",
    "Mexico": "Mexico City",
    "Moldova": "Chisinau",
    "Monaco": "Monaco",
    "Mongolia": "Ulaanbaatar",
    "Montenegro": "Podgorica",
    "Morocco": "Rabat",
    "Mozambique": "Maputo",
    "Myanmar (Burma)": "Nay Pyi Taw",
    "Namibia": "Windhoek",
    "Nauru": "No official capital",
    "Nepal": "Kathmandu",
    "Netherlands": "Amsterdam",
    "New Zealand": "Wellington",
    "Nicaragua": "Managua",
    "Niger": "Niamey",
    "Nigeria": "Abuja",
    "North Korea": "Pyongyang",
    "North Macedonia (Macedonia)": "Skopje",
    "Northern Ireland": "Belfast",
    "Norway": "Oslo",
    "Oman": "Muscat",
    "Pakistan": "Islamabad",
    "Palau": "Melekeok",
    "Panama": "Panama City",
    "Papua New Guinea": "Port Moresby",
    "Paraguay": "Asuncion",
    "Peru": "Lima",
    "Philippines": "Manila",
    "Poland": "Warsaw",
    "Portugal": "Lisbon",
    "Qatar": "Doha",
    "Romania": "Bucharest",
    "Russia": "Moscow",
    "Rwanda": "Kigali",
    "Saint Kitts and Nevis": "Basseterre",
    "Saint Lucia": "Castries",
    "Saint Vincent and the Grenadines": "Kingstown",
    "Samoa": "Apia",
    "San Marino": "San Marino",
    "Sao Tome and Principe": "Sao Tome",
    "Saudi Arabia": "Riyadh",
    "Scotland": "Edinburgh",
    "Senegal": "Dakar",
    "Serbia": "Belgrade",
    "Seychelles": "Victoria",
    "Sierra Leone": "Freetown",
    "Singapore": "Singapore",
    "Slovakia": "Bratislava",
    "Slovenia": "Ljubljana",
    "Solomon Islands": "Honiara",
    "Somalia": "Mogadishu",
    "South Africa": "Pretoria, Bloemfontein, Cape Town",
    "South Korea": "Seoul",
    "South Sudan": "Juba",
    "Spain": "Madrid",
    "Sri Lanka": "Sri Jayawardenapura Kotte",
    "Sudan": "Khartoum",
    "Suriname": "Paramaribo",
    "Sweden": "Stockholm",
    "Switzerland": "Bern",
    "Syria": "Damascus",
    "Taiwan": "Taipei",
    "Tajikistan": "Dushanbe",
    "Tanzania": "Dodoma",
    "Thailand": "Bangkok",
    "Togo": "Lome",
    "Tonga": "Nuku'alofa",
    "Trinidad and Tobago": "Port of Spain",
    "Tunisia": "Tunis",
    "Türkiye (Turkey)": "Ankara",
    "Turkmenistan": "Ashgabat",
    "Tuvalu": "Funafuti",
    "Uganda": "Kampala",
    "Ukraine": "Kyiv or Kiev",
    "United Arab Emirates": "Abu Dhabi",
    "United Kingdom": "London",
    "United States": "Washington D.C.",
    "Uruguay": "Montevideo",
    "Uzbekistan": "Tashkent",
    "Vanuatu": "Port Vila",
    "Vatican City": "Vatican City",
    "Venezuela": "Caracas",
    "Vietnam": "Hanoi",
    "Wales": "Cardiff",
    "Yemen": "Sana'a",
    "Zambia": "Lusaka",
    "Zimbabwe": "Harare"
}


arabic_male = [
    "Mohamed",
    "Mahmoud",
    "Mustafa",
    "Yassin",
    "Taha",
    "Khaled",
    "Hamza",
    "Bilal",
    "Ibrahim",
    "Hassan",
    "Hussein",
    "Karim",
    "Tareq",
    "Abdel-Rahman",
    "Ali",
    "Omar",
    "Halim",
    "Murad",
    "Selim",
    "Abdallah",
    "Fadi",
    "Habib",
    "Ahmed",
    "Ali",
    "Yousouf",
    "Omar",
    "Adam",
    "Abd",
    "Khaled",
    "Fahd"
]

arabic_female = [
    "Shaimaa",
    "Fatma",
    "Maha",
    "Reem",
    "Farida",
    "Aya",
    "Shahd",
    "Ashraqat",
    "Sahar",
    "Fatin",
    "Doha",
    "Fajr",
    "Suha",
    "Rowan",
    "Hosniya",
    "Hasnaa",
    "Hosna",
    "Gamila",
    "Gamalat",
    "Habiba",
    "Mariam",
    "Malak",
    "Habiba",
    "Hana",
    "Farah",
    "Marwa",
    "Nada",
    "Salma"
]

arabic_surnames = [
    "Ansari",
    "Khan",
    "Mirza",
    "Sayyed",
    "Shah",
    "Shaikh",
    "Sheikh",
]

english_surnames = [
    "Smith",
    "Jones",
    "Taylor",
    "Brown",
    "Williams",
    "Wilson",
    "Johnson",
    "Davies",
    "Robinson",
    "Wright",
    "Thompson",
    "Evans",
    "Walker",
    "White",
    "Roberts",
    "Green",
    "Hall",
    "Wood",
    "Jackson",
    "Clark"
]

english_male = [
    "Peter",
    "Pierre",
    "George",
    "John",
    "Mina",
    "Beshoi",
    "Kirollos",
    "Mark",
    "Noah",
    "William",
    "Thomas",
    "Leo",
    "Liam",
    "Jacob",
    "Nathan",
    "Arthur",
    "Felix",
    "Oliver",
    "Elijah",
    "James",
    "Benjamin",
    "Lucas",
    "Henry",
    "Theodore",
    "Robert",
    "Micheal",
    "David", 
    "Richard", 
    "Charles", 
    "Joseph", 
    "Steve",
    "Mateo",
    "Bautista",
    "Juan",
    "Felipe",
    "Bruno",
    "Noah",
    "Benicio",
    "Thiago",
    "Ciro",
    "Liam"
]

english_female = [
    "Mary",
    "Patricia",
    "Linda",
    "Barbara",
    "Elizabeth",
    "Jennifer",
    "Maria",
    "Susan",
    "Margaret",
    "Dorothy",
    "Olivia",
    "Emma",
    "Charlotte",
    "Amelia",
    "Ava",
    "Sophia",
    "Isabella",
    "Mia",
    "Evelyn",
    "Harper",
    "Irene",
]


qualifications = [
        "High school",
        "Diploma in Fire safety",
        "Diploma in Health safety",
        "Diploma in Pharmacy",
        "Bachelor of Arts (B.A)", 
        "Bachelor of Fine Arts (B.F.A)",
        "Bachelor of Business Administration (B.B.A.)",
        "Integrated Law course (B.A + L.L.B.)",
        "Bachelor of Journalism and Mass Communication (B.J.M.)",
        "Bachelor of Fashion Design (B.F.D.)"
        "Bachelor of Science", 
        "Bachelor of Science (Artificial Intelligence)", 
        "Bachelor of Science (Information Technology)", 
        "Bachelor of Science (Computer Science)", 
        "Bachelor of Science (Data Science)", 
        "Bachelor of Commerce (B.Com)",
        "Bachelor of Management Studies (B.Ms))",
        "Bachelor of Enginnering (Civil)",
        "Bachelor of Enginnering (Electronics)",
        "Bachelor of Enginnering (Electronic & Telecommunications)",
        "Bachelor of Enginnering (Mechanical)",
        "Bachelor of Enginnering (Computer)",
        "Bachelor of Enginnering (Chemical engineering)",
        "Bachelor of Enginnering (Nuclear engineering)",
        "Bachelor of Pharmacy (B.Pharm)",
        "Bachelor of Unani Medicine (BUMS)",
        "Bachelor of Ayurvedic Medicine (BAMS)",
        "Bachelor of Medicine, Bachelor of Surgery (MBBS)",
        "Doctor of Medicine (MD)",
        "Master of Arts",
        "Master of Science",
        "Master of Science (Artificial Intelligence)", 
        "Master of Science (Information Technology)", 
        "Master of Science (Computer Science)",
        "Master of Science (Cloud Computing)",
        "Master of Science (Data Science)",
        "Master of bussiness administration (MBA)",
        "Master of managemnt studies (MMS)",
        "Master of Enginnering (Civil)",
        "Master of Enginnering (Electronics)",
        "Master of Enginnering (Electronic & Telecommunications)",
        "Master of Enginnering (Mechanical)",
        "Master of Enginnering (Computer)",
        "Master of Enginnering (Chemical engineering)",
        "Master of Enginnering (Nuclear engineering)",
        "NEEBOSH",
        "Phd",
    ]


from random import randint
from countries import countries
from countries_capital import countries_capital
from qualifications import qualifications
from get_name_gender_religion import get_name_gender_religion
from uuid import uuid1
from datetime import date, datetime

def get_address(nationality):
    country = nationality
    region = countries_capital[nationality]
    street = f"{randint(11, 124)}th street"
    house = f"House no {randint(1, 30)}"
    return f"{house}, {street}, {region}, {country}"

def get_skin_color():
    skin_colors = ("white","brown", "pale", "black")
    return skin_colors[randint(0, len(skin_colors) - 1)]

def get_eye_color(skin_color):
    eye_colors = []
    if skin_color == "white" or skin_color == "pale":
        eye_colors = ["blue", "green", "grey", "brown", "black"]
    else:
        eye_colors = ["brown", "black"]

    return eye_colors[randint(0, len(eye_colors) - 1)]

def get_hair_style(gender):
    hair_styles = ['short', 'medium', 'long', 'bald', 'sides short center long']
    if gender == "female":
        hair_styles.remove("bald")
    return hair_styles[randint(0, len(hair_styles) - 1)]

def get_hair_color(skin_color, age, hair_style):
    hair_color = []
    if skin_color == "white" or skin_color == "pale":
        hair_color = ["blonde", "brown", "black", "red", "white"]
    else:
        hair_color = ["brown", "black"]
    
    if(age > 65):
        hair_color = ["white"]
    
    if(hair_style == "bald"):
        hair_color = ["bald"]

    return hair_color[randint(0, len(hair_color) - 1)]

def get_email(firstname, lastname, age):
    domains = ("gmail", "yahoo", "outlook", "hotmail", "live")
    random_index = randint(0, len(domains) - 1)
    email = f"{firstname.lower()}{lastname.lower()}{date.today().year - age}@{domains[random_index]}.com"
    return email

class get_random_people:

    def get_highest_education(self):
        return qualifications[randint(0, len(qualifications) - 1)]

    def get_nationality(self):
        random_index = randint(0,len(countries) - 1)
        return countries[random_index]

    def get_DOB(self, age):
        year = date.today().year - age
        month = randint(1, 12)
        day = randint(1, 28)
        return datetime(year, month, day).strftime("%b %dth, %Y")

    def get_phone_number(self, length = 10):
        phone_number = str(randint(7, 9))
        for _ in range(0, length - 1):
            phone_number += str(randint(0, 9))
        return phone_number

    def get_person(self):
        firstname, lastname, gender, religion = get_name_gender_religion()
        age = randint(18, 110)
        nationality = self.get_nationality()
        side_bussiness = ("Youtuber", "Vlogger", "Blogger", "Tiktoker", "Gamer")
        skin_color = get_skin_color()
        hair_style = get_hair_style(gender)
        person = {
            "id": str(uuid1()),
            "firstname": firstname,
            "lastname": lastname,
            "dob": self.get_DOB(age),
            "email": get_email(firstname, lastname, age),
            "phone_number": self.get_phone_number(),
            "address": get_address(nationality),
            "gender": gender,
            "religion": religion,
            "age": age,
            "skin_color": skin_color,
            "eye_color": get_eye_color(skin_color),
            "hair_style": hair_style,
            "hair_color": get_hair_color(skin_color, age, hair_style),
            "is_married": True if randint(0, 1) else False,
            "highest_education": self.get_highest_education(),
            "occupation": "Bussiness" if randint(0, 1) else "Service",
            "side_bussiness": side_bussiness[randint(0, len(side_bussiness) - 1)],
            "annaul_income_USD": randint(2500, 20000) * 12,
            "nationality": nationality,
            "height_in_feet": round(randint(15, 24) / 10 * 3.281, 1),
            "weight_in_kg": randint(35, 90)    
        }
        return person

    def get_peoples(self, totalPeoples = 10):
        peoples = []
        for _ in range(0, totalPeoples):
            peoples.append(self.get_person())

        return peoples